/*******************************************************************************
 * Copyright (c) 2012 Romain Quinio (http://code.google.com/p/l10n-maven-plugin)
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 ******************************************************************************/
package com.googlecode.l10nmavenplugin.validators.orchestrator;

import static org.junit.Assert.*;

import org.junit.Before;
import org.junit.Test;

import com.googlecode.l10nmavenplugin.model.BundlePropertyFamily;
import com.googlecode.l10nmavenplugin.model.PropertyFamily;
import com.googlecode.l10nmavenplugin.validators.AbstractL10nValidatorTest;
import com.googlecode.l10nmavenplugin.validators.L10nValidator;

public class PropertyFamilyValidatorTest extends AbstractL10nValidatorTest<PropertyFamily> {

  private L10nValidator<PropertyFamily> validator;

  @Override
  @Before
  public void setUp() {
    super.setUp();
    validator = new PropertyFamilyValidator(logger, new String[] { ".excluded" });
  }

  @Test
  public void excludedKeysShouldBeIgnored() {
    String keyExcluded = "ALLP.text.excluded";
    bundleA.put(keyExcluded, "Some text");
    bundleB.put(keyExcluded, "");

    bundleA.put(KEY_OK, "Some text");
    bundleB.put(KEY_OK, "");

    assertFalse(validator.shouldValidate(new BundlePropertyFamily(keyExcluded, propertiesFamily)));
    assertTrue(validator.shouldValidate(new BundlePropertyFamily(KEY_OK, propertiesFamily)));
  }
}
